(**************************************************************)
(* BYPASS: Optimized bypass router *)
(* Author: Mark Hayden, 3/97 *)
(**************************************************************)

val f : unit -> (Trans.rank -> Trans.seqno -> Iovecl.t -> unit) Route.t
